@@ -6,7 +6,6 @@
 
 #include "application.h"
 
-#include "actionsmanager.h"
 #include "audiosettings.h"
 #include "customcommandsmodel.h"
 #include "generalsettings.h"
@@ -16,7 +15,7 @@
 #include "mediaplayer2.h"
 #include "mediaplayer2player.h"
 #include "mousesettings.h"
-#include "mpvobject.h"
+#include "mpvitem.h"
 #include "playbacksettings.h"
 #include "playlistitem.h"
 #include "playlistmodel.h"
@@ -37,6 +36,7 @@
 #include <QDir>
 #include <QDBusConnection>
 #include <QFileInfo>
+#include <QFontDatabase>
 #include <QGuiApplication>
 #include <QMimeDatabase>
 #include <QPointer>
@@ -52,6 +52,7 @@
 #include <QThread>
 #include <KFileItem>
 #include <recentfilesmodel.h>
+#include <actionsmodel.h>
 
 #include <KAboutApplicationDialog>
 #include <KAboutData>
@@ -61,12 +62,13 @@
 #include <KFileMetaData/Properties>
 #include <KLocalizedContext>
 #include <KLocalizedString>
+#include <KWindowConfig>
 
 static QApplication *createApplication(int &argc, char **argv, const QString &applicationName)
 {
     QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    QApplication::setOrganizationName("kde");
+    QApplication::setOrganizationName("KDE");
     QApplication::setApplicationName(applicationName);
     QApplication::setOrganizationDomain("kde.org");
     QApplication::setApplicationDisplayName("Haruna - Video Player");
@@ -101,7 +103,8 @@ Application::Application(int &argc, char **argv, const QString &applicationName)
     // register mpris dbus service
     QString mspris2Name(QStringLiteral("org.mpris.MediaPlayer2.haruna"));
     QDBusConnection::sessionBus().registerService(mspris2Name);
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/org/mpris/MediaPlayer2"), this, QDBusConnection::ExportAdaptors);
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/org/mpris/MediaPlayer2"),
+                                                 this, QDBusConnection::ExportAdaptors);
     // org.mpris.MediaPlayer2 mpris2 interface
     new MediaPlayer2(this);
 
@@ -132,6 +135,8 @@ Application::Application(int &argc, char **argv, const QString &applicationName)
     m_engine->addImageProvider("thumbnail", new ThumbnailImageProvider());
     setupQmlContextProperties();
     m_engine->load(url);
+
+    connect(Global::instance(), &Global::error, this, &Application::error);
 }
 
 Application::~Application()
@@ -166,7 +171,7 @@ void Application::setupAboutData()
     m_aboutData.setCopyrightStatement(i18n("(c) 2019-2021"));
     m_aboutData.setHomepage(QStringLiteral("https://invent.kde.org/multimedia/haruna"));
     m_aboutData.setBugAddress(QStringLiteral("https://bugs.kde.org/enter_bug.cgi?product=Haruna").toUtf8());
-    m_aboutData.setComponentName(QStringLiteral("generic"));
+    m_aboutData.setComponentName(QStringLiteral("haruna"));
     m_aboutData.setDesktopFileName("org.kde.haruna");
 
     m_aboutData.addAuthor(i18n("George Florea Bănuș"),
@@ -192,10 +197,9 @@ void Application::setupCommandLineParser()
 
 void Application::registerQmlTypes()
 {
-    qmlRegisterType<MpvObject>("mpv", 1, 0, "MpvObject");
+    qmlRegisterType<MpvItem>("org.kde.haruna", 1, 0, "MpvItem");
     qRegisterMetaType<PlayListModel*>();
     qRegisterMetaType<PlayListItem*>();
-    qRegisterMetaType<QAction*>();
     qRegisterMetaType<TracksModel*>();
     qRegisterMetaType<KFileMetaData::PropertyMap>("KFileMetaData::PropertyMap");
 }
@@ -226,9 +230,6 @@ void Application::setupQmlSettingsTypes()
 
 void Application::setupQmlContextProperties()
 {
-    auto  actionsManager = new ActionsManager(this);
-    m_engine->rootContext()->setContextProperty(QStringLiteral("actionsManager"), actionsManager);
-
     std::unique_ptr<LockManager> lockManager = std::make_unique<LockManager>();
     std::unique_ptr<SubtitlesFoldersModel> subsFoldersModel = std::make_unique<SubtitlesFoldersModel>();
 
@@ -244,12 +245,16 @@ void Application::setupQmlContextProperties()
 
     m_engine->rootContext()->setContextProperty(QStringLiteral("subsFoldersModel"), subsFoldersModel.release());
 
-    auto customCommandsModel = new CustomCommandsModel();
-    m_engine->rootContext()->setContextProperty(QStringLiteral("customCommandsModel"), customCommandsModel);
-    auto proxyCustomCommandsModel = new ProxyCustomCommandsModel();
-    proxyCustomCommandsModel->setSourceModel(customCommandsModel);
-    m_engine->rootContext()->setContextProperty(QStringLiteral("proxyCustomCommandsModel"), proxyCustomCommandsModel);
 
+    auto actionsModel = new ActionsModel();
+    m_engine->rootContext()->setContextProperty(QStringLiteral("actionsModel"), actionsModel);
+    m_engine->rootContext()->setContextProperty(QStringLiteral("appActions"), &actionsModel->propertyMap);
+    auto proxyActionsModel = new ProxyActionsModel();
+    proxyActionsModel->setSourceModel(actionsModel);
+    m_engine->rootContext()->setContextProperty(QStringLiteral("proxyActionsModel"), proxyActionsModel);
+
+    auto customCommandsModel = new CustomCommandsModel(actionsModel);
+    m_engine->rootContext()->setContextProperty(QStringLiteral("customCommandsModel"), customCommandsModel);
 
     auto recentFilesModel = new RecentFilesModel();
     m_engine->rootContext()->setContextProperty(QStringLiteral("recentFilesModel"), recentFilesModel);
@@ -259,6 +264,29 @@ void Application::setupQmlContextProperties()
                                                 QVariant::fromValue(KAboutData::applicationData()));
 }
 
+void Application::restoreWindowGeometry(QQuickWindow *window) const
+{
+    if(!GeneralSettings::rememberWindowGeometry()) {
+        return;
+    }
+    KConfig dataResource(QStringLiteral("data"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
+    KConfigGroup windowGroup(&dataResource, QStringLiteral("Window"));
+    KWindowConfig::restoreWindowSize(window, windowGroup);
+    KWindowConfig::restoreWindowPosition(window, windowGroup);
+}
+
+void Application::saveWindowGeometry(QQuickWindow *window) const
+{
+    if(!GeneralSettings::rememberWindowGeometry()) {
+        return;
+    }
+    KConfig dataResource(QStringLiteral("data"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
+    KConfigGroup windowGroup(&dataResource, QStringLiteral("Window"));
+    KWindowConfig::saveWindowPosition(window, windowGroup);
+    KWindowConfig::saveWindowSize(window, windowGroup);
+    dataResource.sync();
+}
+
 QUrl Application::configFilePath()
 {
     QUrl url(Global::instance()->appConfigFilePath());
@@ -415,3 +443,9 @@ void Application::openDocs(const QString &page)
 {
     QDesktopServices::openUrl(QUrl(page));
 }
+
+QStringList Application::getFonts()
+{
+    static QFontDatabase *fontDB = new QFontDatabase();
+    return fontDB->families();
+}
