@@ -8,18 +8,18 @@
 #define APPLICATION_H
 
 #include <QAbstractItemModel>
-#include <QAction>
 #include <QApplication>
+#include <QFont>
 #include <QQmlApplicationEngine>
 #include <QObject>
 
 #include <KAboutData>
 #include <KSharedConfig>
 
+class QQuickWindow;
 class KActionCollection;
 class KConfigDialog;
 class KColorSchemeManager;
-class QAction;
 
 class ApplicationEventFilter : public QObject
 {
@@ -54,6 +54,8 @@ public:
     int run();
     QUrl configFilePath();
     QUrl configFolderPath();
+    Q_INVOKABLE void restoreWindowGeometry(QQuickWindow *window) const;
+    Q_INVOKABLE void saveWindowGeometry(QQuickWindow *window) const;
     Q_INVOKABLE bool configFolderExists();
     Q_INVOKABLE QUrl parentUrl(const QString &path);
     Q_INVOKABLE QUrl pathToUrl(const QString &path);
@@ -64,6 +66,7 @@ public:
     Q_INVOKABLE void setGuiStyle(const QString &style);
     Q_INVOKABLE void activateColorScheme(const QString &name);
     Q_INVOKABLE void openDocs(const QString &page);
+    Q_INVOKABLE QStringList getFonts();
 
     static QString version();
     Q_INVOKABLE static bool hasYoutubeDl();
@@ -74,6 +77,7 @@ public:
 
 signals:
     void qmlApplicationMouseLeave();
+    void error(const QString &message);
 
 private:
     void setupWorkerThread();
