@@ -11,13 +11,7 @@
 #include <QSortFilterProxyModel>
 #include <KSharedConfig>
 
-class ProxyCustomCommandsModel : public QSortFilterProxyModel
-{
-    Q_OBJECT
-
-public:
-    explicit ProxyCustomCommandsModel(QObject *parent = nullptr);
-};
+class ActionsModel;
 
 class CustomCommandsModel : public QAbstractListModel
 {
@@ -27,8 +21,10 @@ class CustomCommandsModel : public QAbstractListModel
         QString commandId;
         QString command;
         QString osdMessage;
+        QString shortcut;
         QString type;
-        int order;
+        bool setOnStartup {true};
+        int order {-1};
     };
 
 public:
@@ -39,6 +35,8 @@ public:
         CommandRole,
         OsdMessageRole,
         TypeRole,
+        ShortcutRole,
+        SetOnStartupRole,
     };
 
     // Basic functionality:
@@ -55,6 +53,7 @@ public:
                                        const QString &command,
                                        const QString &osdMessage,
                                        const QString &type);
+    Q_INVOKABLE void toggleCustomCommand(const QString &groupName, int row, bool setOnStartup);
     Q_INVOKABLE void deleteCustomCommand(const QString &groupName, int row);
 
 private:
