@@ -6,6 +6,7 @@
 
 #include "recentfilesmodel.h"
 
+#include "generalsettings.h"
 #include <global.h>
 
 #include <QDebug>
@@ -20,17 +21,10 @@ RecentFilesModel::RecentFilesModel(QObject *parent)
     auto config = KSharedConfig::openConfig(Global::instance()->appConfigFilePath());
     m_recentFilesConfigGroup = config->group(QStringLiteral("RecentFiles"));
     m_recentFilesAction = new KRecentFilesAction(this);
+    m_recentFilesAction->setMaxItems(GeneralSettings::maxRecentFiles());
     m_recentFilesAction->loadEntries(m_recentFilesConfigGroup);
 
-    beginInsertRows(QModelIndex(), 0, m_recentFilesAction->urls().count()-1);
-    for (int i = 0; i < m_recentFilesAction->maxItems(); i++) {
-        auto file = m_recentFilesConfigGroup.readPathEntry(QStringLiteral("File%1").arg(i+1), QString());
-        if (file.isEmpty()) {
-            break;
-        }
-        m_urls.prepend(file);
-    }
-    endInsertRows();
+    populate();
 }
 
 int RecentFilesModel::rowCount(const QModelIndex &parent) const
@@ -46,13 +40,13 @@ QVariant RecentFilesModel::data(const QModelIndex &index, int role) const
     if (!index.isValid())
         return QVariant();
 
-    QUrl url = m_urls.at(index.row());
+    RecentFile recentFile = m_urls.at(index.row());
 
     switch (role) {
     case PathRole:
-        return QVariant(url.path());
+        return QVariant(recentFile.url);
     case NameRole:
-        return QVariant(url.fileName());
+        return QVariant(recentFile.name);
     }
 
     return QVariant();
@@ -67,7 +61,29 @@ QHash<int, QByteArray> RecentFilesModel::roleNames() const
     return roles;
 }
 
-void RecentFilesModel::addUrl(const QString &path)
+void RecentFilesModel::populate()
+{
+    beginResetModel();
+    m_urls.clear();
+    endResetModel();
+
+    m_recentFilesAction->setMaxItems(GeneralSettings::maxRecentFiles());
+    for (int i = 0; i < m_recentFilesAction->maxItems(); i++) {
+        auto file = m_recentFilesConfigGroup.readPathEntry(QStringLiteral("File%1").arg(i + 1), QString());
+        auto name = m_recentFilesConfigGroup.readPathEntry(QStringLiteral("Name%1").arg(i + 1), QString());
+        if (file.isEmpty()) {
+            break;
+        }
+        beginInsertRows(QModelIndex(), 0, 0);
+        RecentFile recentFile;
+        recentFile.url = QUrl(file);
+        recentFile.name = name;
+        m_urls.prepend(recentFile);
+        endInsertRows();
+    }
+}
+
+void RecentFilesModel::addUrl(const QString &path, const QString &name)
 {
     auto config = KSharedConfig::openConfig(Global::instance()->appConfigFilePath());
     QUrl url(path);
@@ -75,18 +91,22 @@ void RecentFilesModel::addUrl(const QString &path)
         url.setScheme("file");
     }
 
-    m_recentFilesAction->addUrl(url, url.fileName());
+    auto _name = name == QString() ? url.fileName() : name;
+    m_recentFilesAction->addUrl(url, _name);
     m_recentFilesAction->saveEntries(m_recentFilesConfigGroup);
     m_recentFilesConfigGroup.sync();
 
-    auto exists = [url](const QUrl &_url) {
-        return _url.path() == url.path();
-    };
+    populate();
+}
+
+void RecentFilesModel::clear()
+{
     beginResetModel();
-    auto result = std::find_if(m_urls.begin(), m_urls.end(), exists);
-    if (result != m_urls.end()) {
-        m_urls.removeAll(*result);
+    for (const auto &url : m_recentFilesAction->urls()) {
+        m_recentFilesAction->removeUrl(url);
     }
-    m_urls.prepend(url);
+    m_recentFilesAction->saveEntries(m_recentFilesConfigGroup);
+    m_recentFilesConfigGroup.sync();
+    m_urls.clear();
     endResetModel();
 }
